/*

Logic to send messages via gwibber

Copyright 2010 Canonical Ltd.

Authors:
    David Barth <david.barth@canonical.com>

This program is free software: you can redistribute it and/or modify it 
under the terms of the GNU General Public License version 3, as published 
by the Free Software Foundation.

This program is distributed in the hope that it will be useful, but 
WITHOUT ANY WARRANTY; without even the implied warranties of 
MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along 
with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <glib.h>
#include <dbus/dbus-glib.h>

#define GWIBBER_ADDRESS    "com.Gwibber.Service"
#define GWIBBER_OBJECT     "/com/gwibber/Service"
#define GWIBBER_INTERFACE  "com.Gwibber.Service"

static DBusGProxy * gwibber_proxy = NULL;

/*
  static */ void
gwibber_response (DBusGProxy * proxy, DBusGProxyCall * call, gpointer data)
{
	g_debug ("gwibber_send_response");

	return;
}

static void
setup_gwibber_proxy (void) {
	DBusGConnection * bus = dbus_g_bus_get(DBUS_BUS_SESSION, NULL);
	g_return_if_fail(bus != NULL);

	if (gwibber_proxy == NULL) {
		gwibber_proxy = dbus_g_proxy_new_for_name(bus,
												  GWIBBER_ADDRESS,
												  GWIBBER_OBJECT,
												  GWIBBER_INTERFACE);
	}
	g_return_if_fail (gwibber_proxy != NULL);

	return;
}

void
gwibber_send (const gchar *msg)
{
	setup_gwibber_proxy ();

	if (gwibber_proxy == NULL) {
		g_warning ("Can not get a gwibber proxy object");
	}

	GValue value = {0};
	g_value_init(&value, G_TYPE_STRING);
	g_value_set_string(&value, msg);

	g_debug ("gwibber_send: %s\n", msg);

	dbus_g_proxy_begin_call(gwibber_proxy,
	                        "SendMessage",
	                        gwibber_response,
	                        NULL,
	                        NULL,
	                        G_TYPE_VALUE,
							&value,
							G_TYPE_INVALID);

	g_value_unset(&value);

	return;
}

